@@ -1,8 +1,7 @@
-//-*- C++ -*-
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2007  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -15,7 +14,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with lingot; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -24,26 +23,43 @@
 #ifndef __LINGOT_AUDIO_H__
 #define __LINGOT_AUDIO_H__
 
-
-//#define ALSA
-
 #ifdef ALSA
 #include <alsa/asoundlib.h>
 #endif
 
+#ifdef JACK
+#include <jack/jack.h>
+#endif
+
 typedef struct _LingotAudio LingotAudio;
 
-struct _LingotAudio
-  {
-  	#ifdef ALSA
-  	snd_pcm_t *capture_handle;
-  	#else
-    int dsp; // file handler.
-    #endif
-  };
+struct _LingotAudio {
 
-LingotAudio* lingot_audio_new(int channels, int rate, int format, char* fdsp);
-void lingot_audio_destroy(LingotAudio* audio);
-int lingot_audio_read(LingotAudio* audio, void* buffer, int size);
+	int audio_system;
+
+#ifdef ALSA
+	snd_pcm_t *capture_handle;
+#endif
+
+	int dsp; // file handler.
+	SAMPLE_TYPE* read_buffer;
+
+#	ifdef JACK
+	jack_port_t *jack_input_port;
+	jack_client_t *jack_client;
+	int nframes;
+#	endif
+
+	char error_message[100];
+};
+
+// creates an audio handler
+LingotAudio* lingot_audio_new(void*);
+
+// destroys an audio handler
+void lingot_audio_destroy(LingotAudio*, void*);
+
+// reads a new piece of signal
+int lingot_audio_read(LingotAudio*, void*);
 
 #endif
