@@ -47,7 +47,6 @@ LingotCore* lingot_core_new(LingotConfig* conf) {
 
 	core->conf = conf;
 	core->running = 0;
-	core->audio = NULL;
 	core->audio = lingot_audio_new(core);
 
 	// since the SPD is simmetrical, we only store the 1st half.
@@ -237,11 +236,6 @@ void lingot_core_read(LingotCore* core) {
 	// | xxxxxxxxxxxxxxxxyyyyaa | aaaaa | bbbbbbb |
 	//  ------------------------------------------
 	//
-
-	//	printf(
-	//			"decimation_input_len = %d, decimation_output_len = %d, decimation_input_index = %d\n",
-	//			core->conf->read_buffer_size, decimation_output_len,
-	//			decimation_input_index);
 }
 
 void lingot_core_compute_fundamental_fequency(LingotCore* core) {
@@ -379,17 +373,26 @@ void lingot_core_start(LingotCore* core) {
 
 /* stop running the core */
 void lingot_core_stop(LingotCore* core) {
-	void* thread_result;
+	//void* thread_result;
 
-	core->running = 0;
+	// threads cancelation
+	if (core->conf->audio_system != AUDIO_SYSTEM_JACK)
+		pthread_cancel(core->thread_input_read);
+	pthread_cancel(core->thread_computation);
 
+	//	core->running = 0;
+	//
 	// wait for the thread exit
 
 	if (core->conf->audio_system != AUDIO_SYSTEM_JACK) {
-		pthread_join(core->thread_input_read, &thread_result);
+		pthread_join(core->thread_input_read, NULL);
+		//		printf("%p %p %i\n", thread_result, PTHREAD_CANCELED, thread_result
+		//				== PTHREAD_CANCELED);
 	}
 
-	pthread_join(core->thread_computation, &thread_result);
+	pthread_join(core->thread_computation, NULL);
+	//	printf("%p %p %i\n", thread_result, PTHREAD_CANCELED, thread_result
+	//			== PTHREAD_CANCELED);
 
 	pthread_attr_destroy(&core->thread_computation_attr);
 	if (core->conf->audio_system != AUDIO_SYSTEM_JACK) {
