@@ -2,7 +2,7 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2007  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -15,7 +15,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with lingot; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -65,7 +65,7 @@ int lingot_signal_is_peak(LingotConfig* conf, FLT* x, int index) {
 	if (x[index] < conf->noise_threshold_nu)
 		return 0;
 
-	for (j = 0; j < conf->peak_order; j++) {
+	for (j = 0; j < conf->peak_half_width; j++) {
 		if (x[index + j] < x[index + j + 1])
 			return 0;
 		if (x[index - j] < x[index - j - 1])
@@ -89,11 +89,11 @@ int lingot_signal_get_fundamental_peak(LingotConfig* conf, FLT *x, FLT* d2x,
 	unsigned int lowest_index = (unsigned int)ceil(conf->min_frequency*(1.0
 			*conf->oversampling/conf->sample_rate)*conf->fft_size);
 
-	if (lowest_index < conf->peak_order)
-		lowest_index = conf->peak_order;
+	if (lowest_index < conf->peak_half_width)
+		lowest_index = conf->peak_half_width;
 
 	// I'll get the PEAK_NUMBER maximum peaks.
-	for (i = lowest_index; i < N - conf->peak_order; i++)
+	for (i = lowest_index; i < N - conf->peak_half_width; i++)
 		if (lingot_signal_is_peak(conf, x, i)) {
 
 			// search a place in the maximums buffer, if it doesn't exists, the
